AffinePoint

Struct AffinePoint 

pub struct AffinePoint<C: PrimeCurveParams> {
    pub(crate) x: C::FieldElement,
    pub(crate) y: C::FieldElement,
    pub(crate) infinity: u8,
}
Point on a Weierstrass curve in affine coordinates.

Fields

x: C::FieldElement

x-coordinate

y: C::FieldElement

y-coordinate

infinity: u8

Is this point the point at infinity? 0 = no, 1 = yes

This is a proxy for Choice, but uses u8 instead to permit const constructors for IDENTITY and GENERATOR.

Implementations

Source

impl<C> AffinePoint<C>

pub const IDENTITY: Self

Additive identity of the group a.k.a. the point at infinity.

pub const GENERATOR: Self

Base point of the curve.

pub fn is_identity(&self) -> Choice

Is this point the point at infinity?

fn to_compact(self) -> Self

Conditionally negate AffinePoint for use with point compaction.

pub(crate) fn try_random<R: TryRng + ?Sized>( rng: &mut R, ) -> Result<Self, R::Error>

Internal RNG that avoids a TryCryptoRng bound so we can use it with group.

TODO(tarcieri): find some way to avoid this?