BasepointTable

Struct BasepointTable 

pub struct BasepointTable<Point, const WINDOW_SIZE: usize> {
    tables: LazyLock<[LookupTable<Point>; WINDOW_SIZE]>,
}
Precomputed lookup table of multiples of a base point, a.k.a. generator.

This type leverages lazy computation, and requires one of the following crate features to be enabled in order to work:

  • std: leverages std::sync::LazyLock
  • critical-section: leverages once_cell::sync::Lazy via the critical-section crate, enabling the feature to be used in no_std contexts.

Fields

tables: LazyLock<[LookupTable<Point>; WINDOW_SIZE]>

Implementations

Source

impl<Point, const WINDOW_SIZE: usize> BasepointTable<Point, WINDOW_SIZE>

pub const fn new() -> Self

Create a new BasepointTable which is lazily initialized on first use and can be bound to a constant.

Computed using the Point’s Group::generator as the base point.

Source

impl<C: PrimeCurveParams, const WINDOW_SIZE: usize> BasepointTable<ProjectivePoint<C>, WINDOW_SIZE>

pub fn mul(&self, k: &Scalar<C>) -> ProjectivePoint<C>

Multiply Point::generator by the given scalar in constant-time, using the precomputed basepoint table to accelerate the scalar multiplication.

pub fn mul_vartime(&self, k: &Scalar<C>) -> ProjectivePoint<C>

Multiply Point::generator by the given scalar in constant-time, using the precomputed basepoint table to accelerate the scalar multiplication.

Security Warning

Variable-time scalar multiplication can potentially leak secret values and should NOT be used with them.